@@ -13,4 +13,4 @@ class ProgressScore(Base): #pylint: disable=[too-few-public-methods]
     name_of_class = "progress-scores"
 
     def __repr__(self):
-        return super().__repr__(['cohort_member','activity','score'])
+        return super().__repr__(['_id','cohort_member_id','activity','score'])
