@@ -14,7 +14,7 @@ class SubmissionGrade(Base): #pylint: disable=[too-few-public-methods]
     name_of_class = "submission-grades"
 
     def __repr__(self):
-        return super().__repr__(['_id','assignment_id','cohort_member_id','grader_id'])
+        return super().__repr__(['_id', 'assignment_id', 'cohort_member_id', 'grader_id', 'total_score'])
 
     def save(self):
         '''
